package com.supervision.chat.client.dto.chat;

import com.supervision.police.vo.ChatReqVO;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;
import java.util.List;

@Data
public class ChatReqDTO {

    @Schema(description = "用户输入的文本")
    private String query;

    @Schema(description = "知识库名称")
    private String knowledge_base_name;

    @Schema(description = "匹配向量数")
    private int top_k;

    @Schema(description = "知识库匹配相关度阈值，取值范围在0-1之间，SCORE越小，相关度越高，取到1相当于不筛选，建议设置在0.5左右")
    private int score_threshold;

    @Schema(description = "历史会话")
    private List<History> history;

    @Schema(description = "流式输出")
    private boolean stream;

    @Schema(description = "LLM 模型名称")
    private String model_name;

    @Schema(description = "LLM 模型温度")
    private double temperature;

    @Schema(description = "限制LLM生成Token数量，默认None代表模型最大值")
    private int max_tokens;

    @Schema(description = "使用的prompt模板名称")
    private String prompt_name;


    private static ChatReqDTO defaultChatReq(){
        ChatReqDTO chatReq = new ChatReqDTO();
        chatReq.setQuery("裴金禄出生日期");
        chatReq.setKnowledge_base_name("裴金禄笔录-薛庆坤测试");
        chatReq.setTop_k(3);
        chatReq.setScore_threshold(1);
        chatReq.setStream(false);
        chatReq.setModel_name("openai-api");
        chatReq.setTemperature(0.7);
        chatReq.setMax_tokens(0);
        chatReq.setPrompt_name("default");
        return chatReq;
    }

    public static ChatReqDTO create(String query, String knowledge_base_name,List<History> history){
        ChatReqDTO chatReq = defaultChatReq();
        chatReq.setQuery(query);
        chatReq.setKnowledge_base_name(knowledge_base_name);
        chatReq.setHistory(history);
        return chatReq;
    }

}
