package com.supervision.police.service.impl;

import cn.hutool.core.lang.Assert;
import com.supervision.chat.client.LangChainChatService;
import com.supervision.chat.client.dto.chat.ChatReqDTO;
import com.supervision.chat.client.dto.chat.ChatResDTO;
import com.supervision.police.domain.ModelCase;
import com.supervision.police.service.ChatService;
import com.supervision.police.service.ModelCaseService;
import com.supervision.police.vo.ChatReqVO;
import com.supervision.police.vo.ChatResVO;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

@Slf4j
@Service
@RequiredArgsConstructor
public class ChatServiceImpl implements ChatService {

    private final LangChainChatService langChainChatService;


    private final ModelCaseService modelCaseService;


    @Override
    public ChatResVO chat(ChatReqVO chatReqVO) {


        Assert.notEmpty(chatReqVO.getQuery(), "query 不能为空");
        Assert.notEmpty(chatReqVO.getCaseId(), "caseId 不能为空");

        ModelCase modelCase = modelCaseService.getById(chatReqVO.getCaseId());
        Assert.notNull(modelCase, "案件不存在");

        log.info("chat: caseNo:{},query{}", modelCase.getCaseNo(), chatReqVO.getQuery());

        ChatResDTO chat = langChainChatService.chat(
                ChatReqDTO.create(chatReqVO.getQuery(), modelCase.getCaseNo(),chatReqVO.getHistory()));

        log.info("chat: caseNo:{},query{},answer:{}", modelCase.getCaseNo(), chatReqVO.getQuery(),chat.getAnswer());

        return new ChatResVO(chat);
    }
}
